(*************************************************************************
 *                                                                       *
 *                    XII Olimpiada Informatyczna                        *
 *                                                                       *
 *   Rozwizanie zadania: LOT (Lot na Marsa)                             *
 *   Plik:                lots2.cpp                                      *
 *   Autor:               Adam Iwanicki                                  *
 *   Opis:                Rozwiazanie alternatywne (nieoptymalne)        *
 *                        Algorytm dziala w czasie O(nlog n)             *
 *                        i pamieci O(n), sprawdza dla kazdego miasta    *
 *                        czy da si z niego objecha przy uyciu        *
 *                        kolejki priorytetowej                          *
 *                                                                       *
 *************************************************************************)
program Lot_s1;

const MAX = 1000000 + 10;
type moja = record                {prosta struktura do przechowywania sumy czsciowej}
              d, num : LongInt;    {wraz z informacj, do ktrego wierzchoka ona naley}
            end;
var 
  i, n, calk, przejscie, size, minpo: LongInt;
  odl, zap, delta   : Array[0..MAX] of LongInt;     {tablice: odlegoci, iloci_paliw, i sum czciowycH}
  res, uzyte        : Array[0..MAX] of Boolean;     {rezultat - czy mona ldowa, i uyte - czy ju przetworzylimy}
  kopiec            : Array[0..MAX] of moja;        {tablica do obsugi kopca}


{Standardowa funkcja do obugi stogu zaczerpnita z Cormena
 przepisana na iteracje - aby mogo sie to zmieci w stosie
 ze wzgldu na rozmiar danych 1,000,000} 
procedure heapify(p:LongInt); {O(h)=O(lgn)}
var l,r,min: LongInt;
    temp:moja;
begin
 while p<size do begin
  l:= p shl 1;
  r:= l+1;
  if (l<=size) and (kopiec[l].d < kopiec[p].d)
    then min:=l
    else min:=p;
  if (r<=size) and (kopiec[r].d < kopiec[min].d)
    then min:=r;
  if min = p then break;
  temp:= kopiec[min];
  kopiec[min]:=kopiec[p];
  kopiec[p]:=temp;
  p:=min;
 end;
end;

{funckja do zdejmowania wierzchoka z czubka stogu}
procedure pop;
begin
    if size > 0 then
     begin
        kopiec[1]:=kopiec[size];
        Dec(size);
        if size>0 then heapify(1);
     end;
end;

{funckja dodajca wierzchoek do stogu}
procedure push(m:moja); 
var j:LongInt;
begin
 inc(size);
 j:=size;
 while (j>1) and (kopiec[j shr 1].d > m.d) do begin
  kopiec[j]:=kopiec[j shr 1];
  j:=j shr 1;
 end;
 kopiec[j]:=m;
end;

{fukcja obliczajca sumy czciowe przy przechodzeniu
  zgodnie z kierunkiem wskazwek zegara, oraz inicjujca
  inne potrzebne zmienn - cakowity bilans paliwa,
  ustawiajca wierzchoki na nieodwiedzone, i dodajca
  je do stogu}
procedure Preprocess1;
var
  i: LongInt;
  m: moja;
begin
  delta[0]:= 0;
  size:=0;
  for i:= 1 to n do
    begin
        delta[i]:= delta[i-1] + zap[i-1] - odl[i-1];       { obliczanie sum czciowych}
        uzyte[i]:= false;
        m.d:= delta[i]; m.num:= i;
        push(m);
    end;
  minpo:=0;
  calk:= delta[n] + zap[n] - odl[n];                        { cakowity bilans paliwa }
end;

{funkcja obliczajca sumy czsciowe przy przechodzeniu
  przeciwnie do ruchu wskazwek zegara}
procedure Preprocess2;
var
  i: LongInt;
  m: moja;
begin
  delta[n]:= 0;
  size:=0;
  for i:=n-1 downto 0 do
    begin
        delta[i]:= delta[i+1] + zap[i+1] - odl[i];      {obliczanie sum czcioowch}
        uzyte[i]:= false;
        m.d:= delta[i]; m.num:= i;
        push(m);
    end;
  minpo:=0;
end;


{funkcja zwracajca aktualne minimum z pominiciem elementw
  ju przetworzonych - usuwanie jest z opnieniem, aby nie
    musie pamita i utrzymywa tablicy z "adresami" elementw}
function min : LongInt;
begin
    while uzyte[kopiec[1].num] do pop;
    min:= kopiec[1].d;
end;

{gwna funkcja sprawdzajca czy dla danego wierzchoka wszystkie
  sumy czciowe s nieujemne}
function sprawdz(i:LongInt): Boolean;
begin
    sprawdz:= (minpo + przejscie >=0) and (min - delta[i] >=0); 
end;

begin
  ReadLn(n); Dec(n);
  for i:=0 to n do ReadLn(zap[i],odl[i]);

  if n=0 then 
    res[0]:= (zap[0] >= odl[0]) {przypadek 1-wierzcholkowy , juz usuniety z tresci zadania}
  else begin
{Przechodzenie stacji zgodnie z ruche wskazwek zegara}
    Preprocess1;
    for i:=0 to n do begin   
       if delta[i]< minpo then minpo:= delta[i];    {aktualicacja minimuw wro wierzchokw przetworzonych}
       przejscie:= calk - delta[i];             {aktualizacja modyfikatora dla wierzchokw przetworzonych}
       res[i]:= sprawdz(i);                     {przypisanie rezultatu proby przejscia}
       uzyte[i]:= true;
     end;
{przechodzenie stacji przeciwnie do ruchu wskazwek zegara }
    Preprocess2;
    for i:=n downto 0 do begin
      if delta[i]< minpo then minpo:= delta[i];
      przejscie:= calk - delta[i];
      res[i]:= res[i] or sprawdz(i);
      uzyte[i]:= true;
     end;
  end;
  for i:=0 to n do if res[i] then WriteLn('TAK') else WriteLn('NIE');
end.