/*************************************************************************
 *                                                                       *
 *                    XII Olimpiada Informatyczna                        *
 *                                                                       *
 *   Rozwizanie zadania: DWA (Dwa przyjecia)                            *
 *   Plik:                dwa.cpp                                        *
 *   Autor:               Krzysztof Onak                                 *
 *   Opis:                Rozwiazanie wzorcowe                           *
 *                        Jezyk: C++                                     *
 *                                                                       *
 *************************************************************************/

#include <cstdio>
#include <vector>

using namespace std;

typedef vector < vector < bool > >Graph;  // reprezentacja macierzowa grafu

// znajduje wierzchoek stopnia nieparzystego
int find_odd(Graph & graph)
{
  int n = graph.size();
  for (int i = 0; i < n; ++i) {
    int degree = 0;
    for (int j = 0; j < n; ++j)
      if (graph[i][j])
        ++degree;
    if (degree % 2 == 1)
      return i;
  }

  return -1;
}

// dzieli graf na dwie czci, tak aby kady wierzchoek mia parzyst liczb ssiadw w swoim zbiorze
void divide(Graph & graph, vector < bool > &result)
{
  int n = graph.size();

  int i = find_odd(graph);
  if (i == -1)
    return;

  // graph to graf G z dowodu

  vector < bool > neigh = graph[i]; // S - zbir ssiadw wierzchoka i

  // usuwam wierzchoek i z grafu
  for (int j = 0; j < n; ++j)
    if (neigh[j]) {
      graph[i][j] = false;
      graph[j][i] = false;
    }

  // odwracam krawdzie w podgrafie indukowanym przez S (ssiedzi wierzchoka i)
  for (int j = 0; j < n; ++j)
    if (neigh[j]) {
      for (int k = j + 1; k < n; ++k)
        if (neigh[k]) {
          graph[j][k] = !graph[j][k];
          graph[k][j] = !graph[k][j];
        }
    }

  // teraz graph to graf H z dowodu
  // wykonuj rekurencyjnie podzia tego grafu
  divide(graph, result);

  // doczam wierzchoek i do zbioru, w ktrym ma on parzyst liczb ssiadw
  int count_A = 0;
  int count_B = 0;
  for (int j = 0; j < n; ++j)
    if (neigh[j])
      if (!result[j])
        ++count_A;
      else
        ++count_B;

  if (count_A % 2 == 0)
    result[i] = false;
  else
    result[i] = true;
}

void print_solution(vector < bool > &result)
{
  int n = result.size();
  int count = 0;
  for (int i = 0; i < n; ++i)
    if (!result[i])
      ++count;
  printf("%d\n", count);
  for (int i = 0; i < n; ++i)
    if (!result[i])
      printf("%d ", i + 1);
  printf("\n");
}

int main()
{
  // wczytuj graf z wejcia
  int n;
  scanf("%d", &n);
  Graph graph(n);
  for (int i = 0; i < n; ++i)
    graph[i].resize(n, false);
  for (int i = 0; i < n; ++i) {
    int m;
    scanf("%d", &m);
    for (int j = 0; j < m; ++j) {
      int k;
      scanf("%d", &k);
      --k;
      graph[i][k] = true;
    }
  }

  // obliczam podzia zbioru
  vector < bool > result(n, false);
  divide(graph, result);

  // wypisuj wynik - jeden ze zbiorw
  print_solution(result);
}
